@@ -1,11 +1,14 @@
-from sqlvalidator.grammar.lexer import SQLStatementParser, to_tokens, ParsingError
+from typing import List
+
+from sqlvalidator.grammar.lexer import SQLStatementParser, ParsingError
+from sqlvalidator.grammar.tokeniser import to_tokens
 
 
 class SQLQuery:
     def __init__(self, sql: str):
         self.sql = sql
         self.validated = False
-        self.errors = []
+        self.errors: List[str] = []
 
     def is_valid(self) -> bool:
         if not self.validated:
